@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import glob
 from importlib import resources
 from pathlib import Path
@@ -16,6 +18,11 @@ class Utils:
             with resources.path(f"dral.templates.{template}", name) as item:
                 return Path(item)
 
+    @staticmethod
+    def get_template_dir(name: str) -> Path:
+        templates_path = Path(__file__).parent / "templates"
+        return templates_path / name
+
     @staticmethod
     def get_svd_file(device: str) -> Optional[Path]:
         devices_path = Path(__file__).parent / "devices"
@@ -32,3 +39,8 @@ class Utils:
         if len(device_info) > 2:
             return svd.stem, device_info[1], device_info[0]
         return svd.stem, "", device_info[0]
+
+    @staticmethod
+    def get_mapping_file(name: str) -> Path:
+        with resources.path("dral.mappings", name) as item:
+            return Path(item)
